ToggleStyle class
- Inheritance
-
- Object
- ThemeExtension<
_BaseToggleStyle> - ToggleStyle
Constructors
-
ToggleStyle({Color? indicatorColor, Gradient? indicatorGradient, Color? backgroundColor, Gradient? backgroundGradient, Color? borderColor, BorderRadiusGeometry? borderRadius, BorderRadiusGeometry? indicatorBorderRadius, BoxBorder? indicatorBorder, List<
BoxShadow> ? indicatorBoxShadow, List<BoxShadow> ? boxShadow}) -
Default constructor for ToggleStyle.
const
Properties
- backgroundColor → Color?
-
Background color of the switch.
final
- backgroundGradient → Gradient?
-
Gradient of the background. Overwrites backgroundColor if not
null.final - borderColor → Color?
-
Border color of the switch.
final
- borderRadius → BorderRadiusGeometry?
-
BorderRadius of the switch.
final
-
boxShadow
→ List<
BoxShadow> ? -
Shadow for the Container in the background.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- indicatorBorder → BoxBorder?
-
BorderRadius of the indicator.
final
- indicatorBorderRadius → BorderRadiusGeometry?
-
BorderRadius of the indicator.
final
-
indicatorBoxShadow
→ List<
BoxShadow> ? -
Shadow for the indicator Container.
final
- indicatorColor → Color?
-
Background color of the indicator.
final
- indicatorGradient → Gradient?
-
Gradient of the indicator. Overwrites indicatorColor if not
null.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setteroverride
Methods
-
copyWith(
{Color? indicatorColor, Gradient? indicatorGradient, Color? backgroundColor, Gradient? backgroundGradient, Color? borderColor, BorderRadiusGeometry? borderRadius, BorderRadiusGeometry? indicatorBorderRadius, BoxBorder? indicatorBorder, List< BoxShadow> ? indicatorBoxShadow, List<BoxShadow> ? boxShadow}) → ToggleStyle -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ToggleStyle other, double t) → ToggleStyle - Linearly interpolate with another ThemeExtension object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override